@@ -10,6 +10,7 @@ return
 {
     taglist = require("awful.widget.taglist");
     tasklist = require("awful.widget.tasklist");
+    layoutlist = require("awful.widget.layoutlist");
     button = require("awful.widget.button");
     launcher = require("awful.widget.launcher");
     prompt = require("awful.widget.prompt");
@@ -21,6 +22,8 @@ return
     watch = require("awful.widget.watch");
     only_on_screen = require("awful.widget.only_on_screen");
     clienticon = require("awful.widget.clienticon");
+    calendar_popup = require("awful.widget.calendar_popup");
+    common = require("awful.widget.common");
 }
 
 -- vim: filetype=lua:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:textwidth=80
