@@ -16,7 +16,7 @@ local color = require("gears.color")
 local surface = require("gears.surface")
 local beautiful = require("beautiful")
 local cairo = require("lgi").cairo
-local util = require("awful.util")
+local gtable = require("gears.table")
 local setmetatable = setmetatable
 local type = type
 local unpack = unpack or table.unpack -- luacheck: globals unpack (compatibility with Lua 5.1)
@@ -138,29 +138,29 @@ end
 --![Usage example](../images/AUTOGEN_wibox_container_background_bg.svg)
 --
 -- @usage
---local text_widget = {
---    text   = 'Hello world!',
---    widget = wibox.widget.textbox
---}
---parent : setup {
---    {
---        text_widget,
---        bg     = '#ff0000',
---        widget = wibox.container.background
---    },
---    {
---        text_widget,
---        bg     = '#00ff00',
---        widget = wibox.container.background
---    },
---    {
---        text_widget,
---        bg     = '#0000ff',
---        widget = wibox.container.background
---    },
---    spacing = 10,
---    layout  = wibox.layout.fixed.vertical
---}
+-- local text_widget = {
+--     text   = 'Hello world!',
+--     widget = wibox.widget.textbox
+-- }
+-- parent : setup {
+--     {
+--         text_widget,
+--         bg     = '#ff0000',
+--         widget = wibox.container.background
+--     },
+--     {
+--         text_widget,
+--         bg     = '#00ff00',
+--         widget = wibox.container.background
+--     },
+--     {
+--         text_widget,
+--         bg     = '#0000ff',
+--         widget = wibox.container.background
+--     },
+--     spacing = 10,
+--     layout  = wibox.layout.fixed.vertical
+-- }
 -- @property bg
 -- @param bg A color string, pattern or gradient
 -- @see gears.color
@@ -184,29 +184,29 @@ end
 --![Usage example](../images/AUTOGEN_wibox_container_background_fg.svg)
 --
 -- @usage
---local text_widget = {
---    text   = 'Hello world!',
---    widget = wibox.widget.textbox
---}
---parent : setup {
---    {
---        text_widget,
---        fg     = '#ff0000',
---        widget = wibox.container.background
---    },
---    {
---        text_widget,
---        fg     = '#00ff00',
---        widget = wibox.container.background
---    },
---    {
---        text_widget,
---        fg     = '#0000ff',
---        widget = wibox.container.background
---    },
---    spacing = 10,
---    layout  = wibox.layout.fixed.vertical
---}
+-- local text_widget = {
+--     text   = 'Hello world!',
+--     widget = wibox.widget.textbox
+-- }
+-- parent : setup {
+--     {
+--         text_widget,
+--         fg     = '#ff0000',
+--         widget = wibox.container.background
+--     },
+--     {
+--         text_widget,
+--         fg     = '#00ff00',
+--         widget = wibox.container.background
+--     },
+--     {
+--         text_widget,
+--         fg     = '#0000ff',
+--         widget = wibox.container.background
+--     },
+--     spacing = 10,
+--     layout  = wibox.layout.fixed.vertical
+-- }
 -- @property fg
 -- @param fg A color string, pattern or gradient
 -- @see gears.color
@@ -233,41 +233,41 @@ end
 --![Usage example](../images/AUTOGEN_wibox_container_background_shape.svg)
 --
 -- @usage
---parent : setup {
---    {
---        -- Adding a shape without margin may result in cropped output
---        {
---            text   = 'Hello world!',
---            widget = wibox.widget.textbox
---        },
---        shape              = gears.shape.hexagon,
---        bg                 = beautiful.bg_normal,
---        shape_border_color = beautiful.border_color,
---        shape_border_width = beautiful.border_width,
---        widget             = wibox.container.background
---    },
---    {
---        -- To solve this, use a margin
---        {
---            {
---                text   = 'Hello world!',
---                widget = wibox.widget.textbox
---            },
---            left   = 10,
---            right  = 10,
---            top    = 3,
---            bottom = 3,
---            widget = wibox.container.margin
---        },
---        shape              = gears.shape.hexagon,
---        bg                 = beautiful.bg_normal,
---        shape_border_color = beautiful.border_color,
---        shape_border_width = beautiful.border_width,
---        widget             = wibox.container.background
---    },
---    spacing = 10,
---    layout  = wibox.layout.fixed.vertical
---}
+-- parent : setup {
+--     {
+--         -- Adding a shape without margin may result in cropped output
+--         {
+--             text   = 'Hello world!',
+--             widget = wibox.widget.textbox
+--         },
+--         shape              = gears.shape.hexagon,
+--         bg                 = beautiful.bg_normal,
+--         shape_border_color = beautiful.border_color,
+--         shape_border_width = beautiful.border_width,
+--         widget             = wibox.container.background
+--     },
+--     {
+--         -- To solve this, use a margin
+--         {
+--             {
+--                 text   = 'Hello world!',
+--                 widget = wibox.widget.textbox
+--             },
+--             left   = 10,
+--             right  = 10,
+--             top    = 3,
+--             bottom = 3,
+--             widget = wibox.container.margin
+--         },
+--         shape              = gears.shape.hexagon,
+--         bg                 = beautiful.bg_normal,
+--         shape_border_color = beautiful.border_color,
+--         shape_border_width = beautiful.border_width,
+--         widget             = wibox.container.background
+--     },
+--     spacing = 10,
+--     layout  = wibox.layout.fixed.vertical
+-- }
 -- @property shape
 -- @param shape A function taking a context, width and height as arguments
 -- @see gears.shape
@@ -334,33 +334,33 @@ end
 --![Usage example](../images/AUTOGEN_wibox_container_background_clip.svg)
 --
 -- @usage
---parent : setup {
---    {
---        -- Some content may be outside of the shape
---        {
---            text   = 'Hello\nworld!',
---            widget = wibox.widget.textbox
---        },
---        shape              = gears.shape.circle,
---        bg                 = beautiful.bg_normal,
---        shape_border_color = beautiful.border_color,
---        widget             = wibox.container.background
---    },
---    {
---        -- To solve this, clip the content
---        {
---            text   = 'Hello\nworld!',
---            widget = wibox.widget.textbox
---        },
---        shape_clip         = true,
---        shape              = gears.shape.circle,
---        bg                 = beautiful.bg_normal,
---        shape_border_color = beautiful.border_color,
---        widget             = wibox.container.background
---    },
---    spacing = 10,
---    layout  = wibox.layout.fixed.vertical
---}
+-- parent : setup {
+--     {
+--         -- Some content may be outside of the shape
+--         {
+--             text   = 'Hello\nworld!',
+--             widget = wibox.widget.textbox
+--         },
+--         shape              = gears.shape.circle,
+--         bg                 = beautiful.bg_normal,
+--         shape_border_color = beautiful.border_color,
+--         widget             = wibox.container.background
+--     },
+--     {
+--         -- To solve this, clip the content
+--         {
+--             text   = 'Hello\nworld!',
+--             widget = wibox.widget.textbox
+--         },
+--         shape_clip         = true,
+--         shape              = gears.shape.circle,
+--         bg                 = beautiful.bg_normal,
+--         shape_border_color = beautiful.border_color,
+--         widget             = wibox.container.background
+--     },
+--     spacing = 10,
+--     layout  = wibox.layout.fixed.vertical
+-- }
 -- @property shape_clip
 -- @tparam boolean value If the shape clip is enable
 
@@ -405,7 +405,7 @@ local function new(widget, bg, shape)
         enable_properties = true,
     })
 
-    util.table.crush(ret, background, true)
+    gtable.crush(ret, background, true)
 
     ret._private.shape = shape
 
@@ -419,16 +419,14 @@ function background.mt:__call(...)
     return new(...)
 end
 
---Imported documentation
-
-
---- Get a widex index.
+--
+--- Get a widget index.
 -- @param widget The widget to look for
 -- @param[opt] recursive Also check sub-widgets
--- @param[opt] ... Aditional widgets to add at the end of the \"path\"
+-- @param[opt] ... Additional widgets to add at the end of the path
 -- @return The index
 -- @return The parent layout
--- @return The path between \"self\" and \"widget\"
+-- @return The path between self and widget
 -- @function index
 
 --- Get all direct and indirect children widgets.
@@ -588,39 +586,37 @@ end
 -- in its local coordinate system.
 -- @see mouse
 
-
---Imported documentation
-
-
---- Disconnect to a signal.
--- @tparam string name The name of the signal
--- @tparam function func The callback that should be disconnected
+--
+--- Disconnect from a signal.
+-- @tparam string name The name of the signal.
+-- @tparam function func The callback that should be disconnected.
 -- @function disconnect_signal
 
 --- Emit a signal.
 --
--- @tparam string name The name of the signal
+-- @tparam string name The name of the signal.
 -- @param ... Extra arguments for the callback functions. Each connected
---   function receives the object as first argument and then any extra arguments
---   that are given to emit_signal()
+--   function receives the object as first argument and then any extra
+--   arguments that are given to emit_signal().
 -- @function emit_signal
 
 --- Connect to a signal.
--- @tparam string name The name of the signal
--- @tparam function func The callback to call when the signal is emitted
+-- @tparam string name The name of the signal.
+-- @tparam function func The callback to call when the signal is emitted.
 -- @function connect_signal
 
---- Connect to a signal weakly. This allows the callback function to be garbage
--- collected and automatically disconnects the signal when that happens.
+--- Connect to a signal weakly.
+--
+-- This allows the callback function to be garbage collected and
+-- automatically disconnects the signal when that happens.
 --
 -- **Warning:**
 -- Only use this function if you really, really, really know what you
 -- are doing.
--- @tparam string name The name of the signal
--- @tparam function func The callback to call when the signal is emitted
+-- @tparam string name The name of the signal.
+-- @tparam function func The callback to call when the signal is emitted.
 -- @function weak_connect_signal
 
-
 return setmetatable(background, background.mt)
 
 -- vim: filetype=lua:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:textwidth=80
